/*
 * This file is a part of Winix
 * and is not publicly distributed
 * 
 * Copyright (c) 2008-2010, Tomasz Sowa
 * All rights reserved.
 * 
 */
 
#include "createticket.h"
#include "functions/functions.h"
#include "sessiondata.h"



namespace Ticket
{



CreateTicket::CreateTicket()
{
	fun.url = L"createticket";
}


void CreateTicket::SetTDb(TDb * ptdb)
{
	tdb = ptdb;
}


void CreateTicket::SetTicketInfo(TicketInfo * pinfo)
{
	ticket_info = pinfo;
}




bool CreateTicket::HasAccess()
{
	if( cur->request->is_item || !system->HasWriteAccess(*cur->request->dir_tab.back()) )
		return false;
	
	if( !system->mounts.pmount || system->mounts.pmount->type != ticket_info->mount_type_ticket )
		return false;

return true;
}



void CreateTicket::AddTicket(Ticket & ticket, Item & item)
{
	ticket.file_id = item.id;
	cur->request->status = tdb->AddTicket(ticket);

	if( cur->request->status == WINIX_ERR_OK )
	{
		// sending notification
		notify_msg.code           = WINIX_NOTIFY_CODE_ADD;
		notify_msg.template_index = ticket_info->template_index;
		notify_msg.dir_link       = config->url_proto;
		notify_msg.dir_link      += config->base_url;
		system->dirs.MakePath(item.parent_id, notify_msg.dir_link, false);
		notify_msg.item_link      = notify_msg.dir_link;
		notify_msg.item_link     += item.url;

		system->notify.ItemChanged(notify_msg);
	}
}




void CreateTicket::Submit(Ticket & ticket, Item & item)
{
	if( functions->CheckAbuse() )
		return;

	functions->SetUser(item);
	item.privileges = 0644; // !! tymczasowo
	item.parent_id  = cur->request->dir_tab.back()->id;
		
	// adding without notificating
	cur->request->status = system->AddFile(item, false);

	if( cur->request->status == WINIX_ERR_OK )
		AddTicket(ticket, item);
	
	if( cur->request->status == WINIX_ERR_OK )
	{
		log << log2 << "CreateTicket: added a new ticket" << logend;
		RemoveTmpTicket();
		system->RedirectTo(item);
	}
	else
	{
		log << log1 << "CreateTicket: problem with adding a new ticket, error code: "
			<< cur->request->status << logend;
	}
}



void CreateTicket::RemoveTmpTicket()
{
	SessionData * session_data = reinterpret_cast<SessionData*>(
								 cur->session->plugin_data.Get(ticket_info->plugin_id) );

	long dir_id = cur->request->dir_tab.back()->id;
	session_data->create_ticket_map.erase(dir_id);
	session_data->create_file_map.erase(dir_id);
}



Ticket & CreateTicket::PrepareTicket()
{
	SessionData * session_data = reinterpret_cast<SessionData*>(
								 cur->session->plugin_data.Get(ticket_info->plugin_id) );

	long dir_id     = cur->request->dir_tab.back()->id;
	Ticket & ticket = session_data->GetTicket(dir_id, session_data->create_ticket_map);

return ticket;
}


std::vector<long> & CreateTicket::PrepareFileMap()
{
	SessionData * session_data = reinterpret_cast<SessionData*>(
								 cur->session->plugin_data.Get(ticket_info->plugin_id) );

	long dir_id = cur->request->dir_tab.back()->id;
	std::vector<long> & file_map = session_data->GetFileTab(dir_id, session_data->create_file_map);

return file_map;
}


void CreateTicket::MakePost()
{
	ticket_info->Clear();
	ticket_info->FindCurrentConf();

	Ticket & ticket = PrepareTicket();
	Item   & item   = cur->request->item;
	ticket_info->ticket = &ticket;
	std::vector<long> & file_map = PrepareFileMap();

	ticket_info->ReadTicketParams(ticket, false, &file_map);
	functions->ReadItem(item, Item::file);

	if( !cur->request->IsPostVar(L"fileuploadsubmit") )
		Submit(ticket, item);
}



void CreateTicket::MakeGet()
{
	ticket_info->Clear();
	ticket_info->FindCurrentConf();

	Ticket & ticket = PrepareTicket();
	ticket_info->ticket = &ticket;
}




} // namespace
